@@ -77,7 +77,7 @@ fn add_new_session(conn: Conn) -> Conn {
     resp_headers.insert(
         "Set-Cookie".to_owned(),
         // Max Age - 5 days
-        format!("confetti_session_id={}; Max-Age=432000", session_id),
+        format!("confetti_session_id={}; Max-Age=432000; Path=/", session_id),
     );
     return Conn {
         assigns: assigns,
